@@ -20,10 +20,6 @@ use Data::Dump qw(dump);
 use Data::Dumper;
 use IO::Tee;
 use feature 'say';
-use Switch::Back;
-use feature 'smartmatch';
-no warnings 'experimental::smartmatch';
-
 use Sim::OPT;
 use Sim::OPT::Morph;
 use Sim::OPT::Sim;
@@ -43,13 +39,24 @@ no warnings;
 #@EXPORT   = qw(); # our @EXPORT_OK = ( @{ $EXPORT_TAGS{'all'} } );
 our @EXPORT = qw( descend prepareblank tee ); # our @EXPORT = qw( );
 
-$VERSION = '0.169'; # our $VERSION = '';
+$VERSION = '0.167'; # our $VERSION = '';
 $ABSTRACT = 'Sim::OPT::Descent is an module collaborating with the Sim::OPT module for performing block coordinate descent.';
 
 #########################################################################################
 # HERE FOLLOWS THE CONTENT OF "Descend.pm" - Sim::OPT::Descend
 ##############################################################################
 
+sub _arrays_equal 
+{
+    my ($a_ref, $b_ref) = @_;
+    return 0 if @$a_ref != @$b_ref;
+    for my $i (0 .. $#$a_ref) 
+    {
+        return 0 if $a_ref->[$i] ne $b_ref->[$i];
+    }
+    return 1;
+}
+
 sub odd
 {
     my $number = shift;
@@ -956,7 +963,7 @@ sub descend
         my @blockelts = @{ $blockelts_r };
         foreach my $key ( sort ( keys %varns ) )
         {
-          if ( not($key ~~ @blockelts) )
+          if ( not( grep { $_ eq $key } @blockelts ) )
           {
             $varns{$key} = 1;
           }
@@ -994,7 +1001,7 @@ sub descend
         {
           foreach my $key ( sort ( keys( %varnums ) ) )
           {
-            if ( not($key ~~ @blockelts) )
+            if ( not( grep { $_ eq $key } @blockelts ) )
             {
               $modhs{$key} = $varnums{$key};
               $torecovers{$key} = $carrier{$key};
