@@ -28,9 +28,6 @@ use Data::Dump qw(dump);
 use feature 'say';
 no strict;
 no warnings;
-use Switch::Back;
-use feature 'smartmatch';
-no warnings 'experimental::smartmatch';
 
 use Sim::OPT;
 use Sim::OPT::Morph;
@@ -45,13 +42,24 @@ our @ISA = qw(Exporter); # our @adamkISA = qw(Exporter);
 #@EXPORT_OK   = qw(); # our @EXPORT_OK = ( @{ $EXPORT_TAGS{'all'} } );
 
 @EXPORT = qw( parcoord3d ); # our @EXPORT = qw( );
-$VERSION = '0.01.6';
+$VERSION = '0.01.5';
 $ABSTRACT = 'Sim::OPT::Parcoord3d is a program that can process the CSV data for a bi-dimensional parallel coordinate plot and output an Autolisp file for a 3D parallel coordinate plot.';
 
 #########################################################################################
 # HERE FOLLOWS THE CONTENT OF "Parcoord3d.pm", Sim::OPT::Parcoord3d
 #########################################################################################
 
+sub _arrays_equal 
+{
+    my ($a_ref, $b_ref) = @_;
+    return 0 if @$a_ref != @$b_ref;
+    for my $i (0 .. $#$a_ref) 
+    {
+        return 0 if $a_ref->[$i] ne $b_ref->[$i];
+    }
+    return 1;
+}
+
 sub parcoord3d
 {
 	if ( not ( @ARGV ) )
@@ -341,8 +349,8 @@ sub parcoord3d
 					{
 						my @elems = @{$elem};
 						my @cutelems = @elems[0..2]; # PUT ..2 IF ALSO THE THIRD AXIS HAS TO BE CHECKED FOR NON-REPETITIONS, PUT 1 OTHERWISE.
-						if (scalar(@cutelms) == scalar(@cutelems) && !grep { $cutelms[$_] ne $cutelems[$_] } 0..$#cutelms)
-						{
+						if ( _arrays_equal(\@cutelms, \@cutelems) )
+                                                {
 
 							$counthit++;
 							print "COUNTGROUP: $countgroup, HIT! $counthit\n";
