@@ -32,24 +32,31 @@ use feature 'say';
 no strict;
 no warnings;
 #use warnings::unused;
-use Switch::Back;
-use feature 'smartmatch';
-no warnings 'experimental::smartmatch';
-
 @ISA = qw(Exporter); # our @adamkISA = qw(Exporter);
 #%EXPORT_TAGS = ( DEFAULT => [qw( &opt &prepare )]); # our %EXPORT_TAGS = ( 'all' => [ qw( ) ] );
 #@EXPORT   = qw(); # our @EXPORT_OK = ( @{ $EXPORT_TAGS{'all'} } );
 
 our @EXPORT = qw( newretrieve newreport get_files );
 
-$VERSION = '0.123';
+$VERSION = '0.121';
 $ABSTRACT = 'Sim::OPT::Report is the module used by Sim::OPT to retrieve simulation results.';
 
-#########################################################################################
+##############################################################################
 # HERE FOLLOWS THE CONTENT OF "Retrieve.pm", Sim::OPT::Retrieve
 ##############################################################################
 
 
+sub _arrays_equal 
+{
+    my ($a_ref, $b_ref) = @_;
+    return 0 if @$a_ref != @$b_ref;
+    for my $i (0 .. $#$a_ref) 
+    {
+        return 0 if $a_ref->[$i] ne $b_ref->[$i];
+    }
+    return 1;
+}
+
 sub newretrieve
 {
   my %vals = %main::vals;
