@@ -24,9 +24,6 @@ use Data::Dumper;
 #$Data::Dumper::Terse  = 1;
 use Data::Dump qw(dump);
 use feature 'say';
-use Switch::Back;
-use feature 'smartmatch';
-no warnings 'experimental::smartmatch';
 
 use Sim::OPT;
 use Sim::OPT::Morph;
@@ -42,10 +39,10 @@ use warnings::unused;
 
 our @EXPORT = qw( sim ); # our @EXPORT = qw( );
 
-$VERSION = '0.099'; # our $VERSION = '';
+$VERSION = '0.097'; # our $VERSION = '';
 $ABSTRACT = 'Sim::OPT::Sim is the module used by Sim::OPT to launch simulations once the models have been built.';
 
-#########################################################################################
+##############################################################################
 # HERE FOLLOWS THE CONTENT OF "Sim.pm", Sim::OPT::Sim
 ##############################################################################
 
@@ -57,6 +54,16 @@ $ABSTRACT = 'Sim::OPT::Sim is the module used by Sim::OPT to launch simulations
 #____________________________________________________________________________
 # Activate or deactivate the following function calls depending from your needs
 
+sub _arrays_equal 
+{
+    my ($a_ref, $b_ref) = @_;
+    return 0 if @$a_ref != @$b_ref;
+    for my $i (0 .. $#$a_ref) 
+    {
+        return 0 if $a_ref->[$i] ne $b_ref->[$i];
+    }
+    return 1;
+}
 
 sub sim
 {
